@@ -2,9 +2,5 @@ package CPAN::Packager::DependencyFilter::RPM;
 use Mouse;
 with 'CPAN::Packager::DependencyFilter::Role';
 
-sub filter {
-
-}
-
 __PACKAGE__->meta->make_immutable;
 1;
